import {Component, OnInit, ViewChild} from '@angular/core';
import {NavigationLink} from "../../navigation-link-list/navigation-link-list.component";
import * as moment from "moment";
import {ChangeContext, LabelType, Options} from "ngx-slider-v2";
import {
  ChartComponent,
  ApexAxisChartSeries,
  ApexChart,
  ApexXAxis,
  ApexTitleSubtitle
} from "ng-apexcharts";
import {timeInterval} from "rxjs";
import {FormControl} from "@angular/forms";
import {TaskgroupService} from "../../../api";

export type ChartOptions = {
  series: ApexAxisChartSeries;
  chart: ApexChart;
  xaxis: ApexXAxis;
  title: ApexTitleSubtitle;
};
@Component({
  selector: 'app-taskgroup-activity',
  templateUrl: './taskgroup-activity.component.html',
  styleUrls: ['./taskgroup-activity.component.css']
})
export class TaskgroupActivityComponent implements OnInit{
  defaultNavigationLinkPath: NavigationLink[] = [
    {
      linkText: 'Dashboard',
      routerLink: ['/']
    },
    {
      linkText: 'Statistics',
      routerLink: []
    },
    {
      linkText: 'Taskgroup Activity',
      routerLink: ['/statistics/taskgroup-activity']
    }
  ];


  toppings = new FormControl();
  toppingList: string[] = [];
  selectedSeries: string[] = []
  sliderControl: FormControl = new FormControl()
  dateRange: Date[] = this.createDateRange();
  selectedDateRange: Date[] = this.dateRange;
  value: number = this.dateRange[0].getTime();
  options: Options = {
    stepsArray: this.dateRange.map((date: Date) => {
      return { value: date.getTime() };
    }),
    translate: (value: number, label: LabelType): string => {
      return new Date(value).toDateString();
    },
    floor: 0,
    ceil: this.dateRange.length,
  };

  @ViewChild("chart") chart?: ChartComponent;
  public chartOptions: Partial<ChartOptions> = this.generateChartOptions()

  constructor(private taskgroupService: TaskgroupService) {
  }

  ngOnInit() {
    this.taskgroupService.taskgroupsPathGet().subscribe({
      next: resp => {
        resp.forEach(taskgroupPath => {
          let taskgroupPathName = "";
          taskgroupPath.taskgroupPathNames.forEach(name => taskgroupPathName += (name + "/"))
          this.toppingList.push(taskgroupPathName)
        })
      }
    })
  }


  createDateRange(): Date[] {
    const dates: Date[] = [];
    for (let i: number = 1; i <= 31; i++) {

      dates.push(moment().subtract(30-i, 'd').toDate());
    }
    this.sliderControl.setValue([dates[0], dates[dates.length-1]])
    return dates;
  }

  createDateRangeBetween(minValue: moment.Moment, maxValue: moment.Moment) {
    const dates: Date[] = [];
    const numberDays = maxValue.diff(minValue, 'days');
    for(let i=0; i<=numberDays; i++) {
      dates.push(minValue.add(i, 'd').toDate());
    }
    return dates;
  }

  onUserChangeStart(changeContext: ChangeContext) {

      //console.log("onUserChangeStart" + new Date(changeContext.value));
  }

  onUserChangeStop(changeContext: ChangeContext) {
      //console.log("onUserChangeStop" + new Date(changeContext.highValue!))
  }

  onUserChange(changeContext: ChangeContext) {
    const dateRange = this.createDateRangeBetween(moment(changeContext.value), moment(changeContext.highValue!))
    this.chartOptions = this.generateChartOptions()
  }

  generateChartOptions(): Partial<ChartOptions> {
    return {
      series: this.selectedSeries.map(serie => this.generateSeries(serie)!),
        chart: {
      height: 350,
        type: "bar",
        stacked: false
    },
      title: {
        text: ""
      },
      xaxis: {
        categories: this.selectedDateRange.map(date => date.toDateString())
      }
    };
  }

  generateSeries(serie: string) {
    if(serie == "KIT/") {
      return {
        name: "Marine Sprite",
        data: [44, 55, 41, 37, 22, 43, 21]
      }
    } else if(serie == "Striking Calf") {
      return {
        name: "Striking Calf",
        data: [53, 32, 33, 52, 13, 43, 32]
      }
    } else if(serie == "Tank Picture") {
      return {
        name: "Tank Picture",
        data: [12, 17, 11, 9, 15, 11, 20]
      }
    } else {
      return {
        name: "",
        data: []
      }
    }

  }

  updateSerieSelection() {
    this.chartOptions = this.generateChartOptions()
  }
}
